@@ -285,7 +285,8 @@ struct Tings {
     char _nullchar1;
     uint8_t librecountry;
     
-    int8_t empty2b:2;
+    int8_t reserved1:1;
+    bool DisconnectSensor:1;
 
     bool showcalibrated:1;
     bool showscans:1;
@@ -725,9 +726,9 @@ void mkshorts() {
 void mklabels() {
     LOGSTRING("mklabels\n");
     Tings::Variables *varsptr=data()->vars;
-    varsptr[0].prec=.5f;
+    varsptr[0].prec=1.0f;
     varsptr[1].prec=1.0f;
-    varsptr[2].prec=1.0f;
+    varsptr[2].prec=.5f;
     varsptr[3].prec=.5f;
     varsptr[4].prec=1.0f;
     varsptr[5].prec=1.0f;
@@ -739,7 +740,7 @@ void mklabels() {
     for(unsigned int i=0;i<nrlab;i++) {
         strcpy( varsptr[i].name,usedtext->labels[i].data());
     }
-    data()->mealvar=1;
+    data()->mealvar=0;
     data()->varcount=nrlab;
     mkshorts() ;
 }
